prepare_GNPS: prepare_GNPS

Description Usage Arguments Value Examples

View source: R/GNPS_functions.R

Description

prepare_GNPS

Usage

1
prepare_GNPS(ID = NULL, dir = ".", select = T, overwrite = F, mgf = F)

Arguments

ID

GNPS ID to prepare

dir

Path to put GNPS files

select

Only output features in the feature table found in the CSS matrix

overwrite

Overwrite the directory?

mgf

Download mgf file?

Value

A list of a feature matrix and a chemical similarity matrix (CSS)

Examples

1
prepare_GNPS("0310e20491314ddbbf12d56b592548b4")

askerdb/rCSCS documentation built on April 7, 2020, 10:51 a.m.