Description Usage Arguments Value Examples
View source: R/GNPS_functions.R
prepare_GNPS
1 | prepare_GNPS(ID = NULL, dir = ".", select = T, overwrite = F, mgf = F)
|
ID |
GNPS ID to prepare |
dir |
Path to put GNPS files |
select |
Only output features in the feature table found in the CSS matrix |
overwrite |
Overwrite the directory? |
mgf |
Download mgf file? |
A list of a feature matrix and a chemical similarity matrix (CSS)
1 | prepare_GNPS("0310e20491314ddbbf12d56b592548b4")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.